@@ -15,18 +15,18 @@ var cmdsAddCmd = &cobra.Command{
 	Short: "Add a command to run on a specific event",
 	Long:  `Add a command to run on a specific event.`,
 	Args:  cobra.MinimumNArgs(2),
-	RunE: python(func(_ *cobra.Command, args []string, d *pythonData) error {
-		s, err := d.store.Settings.Get()
+	RunE: withStore(func(_ *cobra.Command, args []string, st *store) error {
+		s, err := st.Settings.Get()
 		if err != nil {
 			return err
 		}
 		command := strings.Join(args[1:], " ")
 		s.Commands[args[0]] = append(s.Commands[args[0]], command)
-		err = d.store.Settings.Save(s)
+		err = st.Settings.Save(s)
 		if err != nil {
 			return err
 		}
 		printEvents(s.Commands)
 		return nil
-	}, pythonConfig{}),
+	}, storeOptions{}),
 }
